@@ -173,7 +173,7 @@ class RecordLoader:
             signalTypeStr = "unknown"
         return signalTypeStr
 
-    def groupByChannel(self, group, recordIds):
+    def groupBy(self, group, recordIds):
         if group is not None:
             raise Exception("groupBy is not implemented by this RecordLoader, can't group by '%s'" % group)
         return {recordId: recordId for recordId in recordIds}
